@@ -1,16 +1,16 @@
-setClass("Mart",
+Mart <- setClass("Mart",
          representation(biomart = "character",
                         host = "character",
                         vschema = "character",
                         version = "character",
                         dataset = "character",
                         filters = "data.frame",
-                        attributes = "data.frame"#,
-                       # archive = "logical"
+                        attributes = "data.frame",
+                        httr_config = "list"
                         ),
          prototype(dataset = "",
-                   vschema="default"#,
-                  # archive = FALSE
+                   vschema="default",
+                   version = "",
+                   httr_config = list(httr::config())
                    )
          )
-
